==============================
Whoosh |release| documentation
==============================

Whoosh was created by `Matt Chaput <mailto:matt@whoosh.ca>`_.
You can view outstanding issues on the
`Whoosh Bitbucket page <http://bitbucket.org/mchaput/whoosh>`_
and get help on the `Whoosh mailing list <http://groups.google.com/group/whoosh>`_.


Contents
========

.. toctree::
    :maxdepth: 2
    
    releases/index
    quickstart
    intro
    glossary
    schema
    indexing
    searching
    parsing
    querylang
    query
    analysis
    stemming
    ngrams
    facets
    highlight
    keywords
    spelling
    api/api
    tech/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

